<?php
/***************************************************************************
 *                                 mysql.php
 *                            -------------------
 *   begin                : Saturday, Feb 13, 2001
 *   copyright            : (C) 2001 The phpBB Group
 *   email                : support@phpbb.com
 *
 *   $Id: mysql.php,v 1.16.2.1 2005/09/18 16:17:20 acydburn Exp $
 *   
 *   2011-08-09   php5.3 fixed by U.Schroeter  
 *   2019-06-03   modified for mysqli
 *
 ***************************************************************************/

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

if(!defined("SQL_LAYER"))
{

define("SQL_LAYER","mysqli");

class sql_db
{

	var $db_connect_id;
	var $query_result;
	var $query_num;
	var $row = array();
	var $rowset = array();
  var $num_queries = 0;

	//
	// Constructor
	//
	function sql_db($sqlserver, $sqluser, $sqlpassword, $database, $persistency = true)
	{

		$this->persistency = $persistency;
		$this->user = $sqluser;
		$this->password = $sqlpassword;
		$this->server = $sqlserver;
		$this->dbname = $database;

		if($this->persistency)
		{
			$this->db_connect_id = new mysqli($this->server, $this->user, $this->password, $this->dbname);
		}
		else
		{
			$this->db_connect_id = new mysqli($this->server, $this->user, $this->password, $this->dbname);
		}
		if($this->db_connect_id)
		{
			return $this->db_connect_id;
		}
		else
		{
			return false;
		}
	}

	//
	// Other base methods
	//
	function sql_close()
	{
		if($this->db_connect_id)
		{
			if(is_object($this->query_result))
			{
        @$this->query_result->free_result();
			}
      $result = @$this->db_connect_id->close();
			return $result;
		}
		else
		{
			return false;
		}
	}

	//
	// Base query method
	//
	function sql_query($query = "", $transaction = FALSE)
	{
		// Remove any pre-existing queries
		unset($this->query_result);
		if($query != "")
    {
      $this->query_result = $this->db_connect_id->query($query);
    }
    if($this->query_result)
    {
  		if(is_object($this->query_result))
      {
  			if ( isset( $this->row[spl_object_hash($this->query_result)] ) ) unset($this->row[spl_object_hash($this->query_result)]);
  			if ( isset( $this->rowset[spl_object_hash($this->query_result)] ) ) unset($this->rowset[spl_object_hash($this->query_result)]);
  			return $this->query_result;
      } else {
        return true;
      }
    }
		else
		{
			return ( $transaction == 'END_TRANSACTION' ) ? true : false;
		}
	}

	//
	// Other query methods
	//
	function sql_numrows($query_id = false)
  {
    if ($query_id===false)
    {
      $query_id=$this->query_result;
    }
		if($query_id)
		{
      return @$query_id->num_rows;
		}
		else
		{
			return false;
		}
	}
	function sql_affectedrows()
	{
		if($this->query_result)
		{
      return @$this->query_result->num_rows;
		}
		else
		{
			return false;
		}
	}
	function sql_numfields($query_id = false)
	{
    if ($query_id===false)
    {
      $query_id=spl_object_hash($this->query_result);
    }
		if($query_id)
		{
			return @$query_id->field_count;
		}
		else
		{
			return false;
		}
	}
	function sql_fieldname($offset, $query_id = false)
	{
		if($query_id===false)
		{
			$query_id=$this->query_id;
		}
		if($query_id)
    {
      return $query_id->fetch_field_direct($offset)['name'];
		}
		else
		{
			return false;
		}
	}
	function sql_fieldtype($offset, $query_id = false)
	{
		if($query_id===false)
		{
			$query_id=$this->query_result;
		}
		if($query_id)
    {
      return $query_id->fetch_field_direct($offset)['type'];
		}
		else
		{
			return false;
		}
	}
	function sql_fetchrow($query_id = false)
	{
		if($query_id===false)
		{
			$query_id=$this->query_result;
		}
		if($query_id)
    {
			$this->row[spl_object_hash($query_id)] = $query_id->fetch_assoc();
			return $this->row[spl_object_hash($query_id)];
		}
		else
		{
			return false;
		}
	}
  function sql_freeresult($query_id = false)
  {
		if($query_id===false)
		{
			$query_id=$this->query_result;
		}

		if ($query_id)
    {
      if (is_object($query_id))
      {
  			unset($this->row[spl_object_hash($query_id)]);
  			unset($this->rowset[spl_object_hash($query_id)]);

  			@$query_id->free_result();
      }
			return true;
		}
		else
		{
			return false;
		}
	}
	function sql_error($query_id = false)
	{
		$result["message"] = @$this->db_connect_id->error;
		$result["code"] = @$this->db_connect_id->errno;

		return $result;
	}

} // class sql_db

} // if ... define

?>
